==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/pl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendarz",
    "Todos" : "Zadania",
    "{actor} created calendar {calendar}" : "{actor} utworzył/-a kalendarz {calendar}",
    "You created calendar {calendar}" : "Utworzyłeś/-aś kalendarz {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} usunął/-ęła kalendarz {calendar} .",
    "You deleted calendar {calendar}" : "Usunąłęś/ęłaś kalendarz {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} zaktualizował/-a kalendarz {calendar} .",
    "You updated calendar {calendar}" : "Zaktualizowałeś/-aś kalendarz {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} współdzieli kalendarz {calendar} z tobą",
    "You shared calendar {calendar} with {user}" : "Współdzielisz kalendarz {calendar} z {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} współdzieli kalendarz {calendar} z {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} zakończył/-a współdzielienie kalendarza {calendar} z tobą",
    "You unshared calendar {calendar} from {user}" : "Zakończyłeś/-aś współdzielenie kalendarza {calendar} z {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zakończył/-a współdzielenie kalendarza {calendar} z {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zakończył/-a wspóldzielenie kalendarza {calendar} od siebie",
    "You shared calendar {calendar} with group {group}" : "Współdzielisz kalendarz {calendar} z grupą {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} współdzieli kalendarz {calendar} z grupą {group}",
    "You unshared calendar {calendar} from group {group}" : "Zakończyłeś współdzielenie kalendarza {calendar} z grupą {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  nie współdzieli kalendarza {calendar} z grupą {group} .",
    "{actor} created event {event} in calendar {calendar}" : "{actor} utworzył/-a wydarzenie {event} w kalendarzu {calendar}",
    "You created event {event} in calendar {calendar}" : "Utworzyłeś/-ał wydarzenie {event} w kalendarzu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} usunął/-ęłą wydarzenie {event} z kalendarza {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usunąłeś/-aś wydarzenie {event} z kalendarza {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} zaktualizował/-a wydarzenie {event} z kalendarza {calendar}",
    "You updated event {event} in calendar {calendar}" : "Zaktualizowałeś/-aś wydarzenie {event} w kalendarzu {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} utworzył/-a zadanie {todo} na liście {calendar}",
    "You created todo {todo} in list {calendar}" : "Utworzyłeś/-aś zadanie {todo} na liście {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} usunął/-ęła zadanie {todo} z listy {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usunąłeś/-ęłaś zadanie {todo} z listy {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} zaktualizował/-a zadanie {todo} na liście {calendar}",
    "You updated todo {todo} in list {calendar}" : "Zaktualizowałeś/-aś zadanie {todo} na liście {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} zakończył zadanie {todo} na liście {calendar}",
    "You solved todo {todo} in list {calendar}" : "Zakończyłeś/-aś zadanie {todo} na liście {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} otworzył ponownie zadanie {todo} na liście {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otworzyłęś/-aś ponownie zadanie {todo} na liście {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendarz</strong> został zmodyfikowany",
    "A calendar <strong>event</strong> was modified" : "<strong>Zdarzenie</strong> kalendarza zostało zmodyfikowane",
    "A calendar <strong>todo</strong> was modified" : "Kalendarz <strong>zadań</strong> został zmieniony",
    "Contact birthdays" : "Urodziny kontaktu",
    "Personal" : "Osobiste",
    "Contacts" : "Kontakty",
    "WebDAV" : "WebDAV",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/pl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendarz",
    "Todos" : "Zadania",
    "Personal" : "Osobiste",
    "{actor} created calendar {calendar}" : "{actor} utworzył/-a kalendarz {calendar}",
    "You created calendar {calendar}" : "Utworzyłeś/-aś kalendarz {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} usunął/-ęła kalendarz {calendar} .",
    "You deleted calendar {calendar}" : "Usunąłęś/ęłaś kalendarz {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} zaktualizował/-a kalendarz {calendar} .",
    "You updated calendar {calendar}" : "Zaktualizowałeś/-aś kalendarz {calendar}",
    "You shared calendar {calendar} as public link" : "Udostępniłeś kalendarz {calendar} jako publiczny link",
    "You removed public link for calendar {calendar}" : "Usunąłeś publiczny link do kalendarza {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} współdzieli kalendarz {calendar} z Tobą",
    "You shared calendar {calendar} with {user}" : "Współdzielisz kalendarz {calendar} z {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} współdzieli kalendarz {calendar} z {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} zakończył/-a współdzielienie kalendarza {calendar} z Tobą",
    "You unshared calendar {calendar} from {user}" : "Zakończyłeś/-aś współdzielenie kalendarza {calendar} z {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zakończył/-a współdzielenie kalendarza {calendar} z {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zakończył/-a wspóldzielenie kalendarza {calendar} od siebie",
    "You shared calendar {calendar} with group {group}" : "Współdzielisz kalendarz {calendar} z grupą {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} współdzieli kalendarz {calendar} z grupą {group}",
    "You unshared calendar {calendar} from group {group}" : "Zakończyłeś współdzielenie kalendarza {calendar} z grupą {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  nie współdzieli kalendarza {calendar} z grupą {group} .",
    "{actor} created event {event} in calendar {calendar}" : "{actor} utworzył/-a wydarzenie {event} w kalendarzu {calendar}",
    "You created event {event} in calendar {calendar}" : "Utworzyłeś/-ał wydarzenie {event} w kalendarzu {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} usunął/-ęłą wydarzenie {event} z kalendarza {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usunąłeś/-aś wydarzenie {event} z kalendarza {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} zaktualizował/-a wydarzenie {event} z kalendarza {calendar}",
    "You updated event {event} in calendar {calendar}" : "Zaktualizowałeś/-aś wydarzenie {event} w kalendarzu {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} utworzył/-a zadanie {todo} na liście {calendar}",
    "You created todo {todo} in list {calendar}" : "Utworzyłeś/-aś zadanie {todo} na liście {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} usunął/-ęła zadanie {todo} z listy {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usunąłeś/-ęłaś zadanie {todo} z listy {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} zaktualizował/-a zadanie {todo} na liście {calendar}",
    "You updated todo {todo} in list {calendar}" : "Zaktualizowałeś/-aś zadanie {todo} na liście {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} zakończył zadanie {todo} na liście {calendar}",
    "You solved todo {todo} in list {calendar}" : "Zakończyłeś/-aś zadanie {todo} na liście {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} otworzył ponownie zadanie {todo} na liście {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otworzyłęś/-aś ponownie zadanie {todo} na liście {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendarz</strong> został zmodyfikowany",
    "A calendar <strong>event</strong> was modified" : "<strong>Zdarzenie</strong> kalendarza zostało zmodyfikowane",
    "A calendar <strong>todo</strong> was modified" : "Kalendarz <strong>zadań</strong> został zmieniony",
    "Contact birthdays" : "Urodziny kontaktu",
    "%s via %s" : "%s przez %s",
    "Invitation canceled" : "Zaproszenie anulowane",
    "Hello %s," : "Witaj %s,",
    "The meeting »%s« with %s was canceled." : "Spotkanie »%s« z %s zostało anulowane.",
    "Invitation updated" : "Zaproszenie zaktualizowane",
    "The meeting »%s« with %s was updated." : "Spotkanie »%s« z %s zostało zaktualizowane.",
    "%s invited you to »%s«" : "%s zaprosił Cię do »%s«",
    "When:" : "Kiedy:",
    "Where:" : "Gdzie: ",
    "Description:" : "Opis:",
    "Link:" : "Link: ",
    "Contacts" : "Kontakty",
    "WebDAV" : "WebDAV",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s",
    "Are you accepting the invitation?" : "Czy akceptujesz zaproszenie?",
    "Save" : "Zapisz",
    "CalDAV server" : "Serwer CalDAV",
    "Send invitations to attendees" : "Wyślij uczestnikom zaproszenia",
    "Please make sure to properly set up the email settings above." : "Upewnij się, że dobrze skonfigurowano powyżej ustawienia poczty e-mail.",
    "Automatically generate a birthday calendar" : "Automatycznie generuj kalendarz urodzin"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
